@@ -6,7 +6,9 @@ OC.L10N.register(
     "Add contacts" : "Ouzhpennañ darempredoù",
     "Loading …" : "O Kargañ ...",
     "Download" : "Pellgargañ",
+    "Send email" : "Kas postel",
     "Groups" : "Strolladoù",
+    "Circles" : "Kelc'hioù",
     "Rename" : "Adenvel",
     "Enabled" : "Aotreet",
     "Delete" : "Dilemel",
@@ -15,21 +17,34 @@ OC.L10N.register(
     "No users or groups" : "Implijourienn pe strodadoù ebet",
     "can edit" : "posuple eo embann",
     "Display name" : "Anv ardivink",
+    "Password protection" : "Gwareziñ gant ur ger-tremen",
+    "Save" : "Enrollañ",
+    "Description" : "Deskrivadur",
     "Invalid image" : "N'eo ket aotreet ar skeudenn",
     "Name" : "Anv",
     "Company" : "Embregerez",
+    "Title" : "Titl",
     "Cancel" : "Arrest",
+    "Search contacts …" : "Klask darempred ...",
     "No results" : "Disoc'h ebet",
+    "Pending" : "O c'hortoz",
     "Close" : "Seriñ",
     "Import" : "Emporzhiañ ",
+    "User" : "Implijer",
+    "Group" : "Stollad",
     "Email" : "Postel",
+    "Admin" : "Merour",
+    "Owner" : "Perc'henner",
+    "Users" : "Implijer",
     "Website" : "Lec'hien web",
+    "Location" : "Lec'hiadur",
     "Home" : "Degemer",
     "Work" : "Labour",
     "Other" : "All",
     "Address" : "Chom-lec'h",
     "City" : "Ker",
     "Country" : "Bro",
+    "Birthday" : "Deiz-ha-bloaz",
     "None" : "Hini ebet",
     "Unknown" : "Dianv"
 },
