@@ -116,7 +116,6 @@ OC.L10N.register(
     "Address book" : "アドレス帳",
     "New contact" : "新しい連絡先",
     "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
-    "The contact doesn't exists anymore on the server." : "連絡先はサーバーに存在しません。",
     "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
     "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
     "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
@@ -155,6 +154,7 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "メンバー{displayName}を削除できませんでした",
     "Could not change the member level to {level}" : "メンバーレベルを{level}に変更できませんでした",
     "Could not accept membership request" : "メンバーシップリクエストを承諾できませんでした",
+    "Chart" : "チャート",
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
     "Add contact in group" : "グループに連絡先を追加",
@@ -237,6 +237,7 @@ OC.L10N.register(
     "Voice" : "音声番号",
     "Car" : "自動車",
     "Work pager" : "ワークページャー",
+    "Manager" : "マネージャー",
     "Social network" : "ソーシャルネットワーク",
     "Relationship to you" : "あなたとの関係",
     "Spouse" : "配偶者",
@@ -249,7 +250,6 @@ OC.L10N.register(
     "Relative" : "親族",
     "Friend" : "友人",
     "Colleague" : "同僚",
-    "Manager" : "マネージャー",
     "Assistant" : "アシスタント",
     "Related contacts" : "関連した連絡先",
     "Agent" : "エージェント",
