@@ -12,6 +12,9 @@ OC.L10N.register(
     "Copy link" : "සබැඳිය පිටපත් කරන්න",
     "First name" : "මුල් නම",
     "Last name" : "අවසන් නම",
+    "Password protection" : "මුරපද ආරක්ෂාව",
+    "Save" : "සුරකින්න",
+    "Description" : "විස්තරය",
     "Invalid image" : "වලංගු නොවන පින්තූරයකි",
     "Name" : "නම",
     "Company" : "සමාගම",
@@ -23,7 +26,13 @@ OC.L10N.register(
     "Select Date" : "දිනය තෝරන්න",
     "Close" : "වසන්න",
     "_{count} error_::_{count} errors_" : ["දෝෂ {count}","දෝෂ {count}"],
+    "User" : "පරිශීලක",
+    "Group" : "සමූහය",
     "Email" : "විද්‍යුත් තැපෑල",
+    "Member" : "සාමාජික",
+    "Admin" : "පරිපාලක",
+    "Owner" : "හිමිකරු",
+    "Users" : "පරිශීලකයින්",
     "Nickname" : "අන්වර්ථ නාමය",
     "Detailed name" : "විස්තරාත්මක නම",
     "Additional names" : "අමතර නම්",
