@@ -186,12 +186,14 @@ class SocialApiService {
 			}
 
 			// search contact in that addressbook, get social data
-			$contact = $addressBook->search($contactId, ['UID'], ['types' => true])[0];
+			$contacts = $addressBook->search($contactId, ['UID'], ['types' => true]);
 
-			if (!isset($contact)) {
+			if (!isset($contacts[0])) {
 				return new JSONResponse([], Http::STATUS_PRECONDITION_FAILED);
 			}
 
+			$contact = $contacts[0];
+
 			if ($network) {
 				$allConnectors = [$this->socialProvider->getSocialConnector($network)];
 			}
